DROP TABLE IF EXISTS title_patterns;
DROP TABLE IF EXISTS artifact_image_objects;
DROP TABLE IF EXISTS artifact_images;
DROP TABLE IF EXISTS mappings;
DROP TABLE IF EXISTS mapped_elements;
DROP TABLE IF EXISTS mapped_methods;
DROP TABLE IF EXISTS settings;
DROP TABLE IF EXISTS admin_settings;
DROP TABLE IF EXISTS e_mapping_statuses;
DROP TABLE IF EXISTS artifacts;
DROP TABLE IF EXISTS diagram_images;


CREATE TABLE e_mapping_statuses
(
  id smallint primary key,
  code varchar(20),
  name varchar(100)
);

DELETE FROM e_mapping_statuses;
INSERT INTO e_mapping_statuses (id, code, name) values (1, 'SYNC', 'Synchronised'); 
INSERT INTO e_mapping_statuses (id, code, name) values (2, 'NO_PAGE', 'Page missing');
INSERT INTO e_mapping_statuses (id, code, name) values (3, 'NO_OBJ', 'Object missing');
INSERT INTO e_mapping_statuses (id, code, name) values (4, 'NOT_SYNC', 'Not synchronised');

CREATE TABLE artifacts
(
  id smallint primary key,
  code varchar(20),
  name varchar(100)
);

DELETE FROM artifacts;
INSERT INTO artifacts (id, code, name) values (1, 'PROC', 'Process');
INSERT INTO artifacts (id, code, name) values (2, 'TRM', 'Term');
INSERT INTO artifacts (id, code, name) values (3, 'REQ', 'Requirement');
INSERT INTO artifacts (id, code, name) values (4, 'BR', 'Business rule');
INSERT INTO artifacts (id, code, name) values (5, 'UC', 'Use case');
INSERT INTO artifacts (id, code, name) values (6, 'ACTR', 'Actor');
INSERT INTO artifacts (id, code, name) values (7, 'PRV', 'Privilege');
INSERT INTO artifacts (id, code, name) values (8, 'ACT', 'Activity');
INSERT INTO artifacts (id, code, name) values (9, 'FCN', 'Function');
INSERT INTO artifacts (id, code, name) values (10, 'IF', 'Interface');
INSERT INTO artifacts (id, code, name) values (11, 'SVC', 'Service');
INSERT INTO artifacts (id, code, name) values (12, 'SCR', 'Screen');
INSERT INTO artifacts (id, code, name) values (13, 'UI', 'UI element');
INSERT INTO artifacts (id, code, name) values (14, 'DOC', 'Document');
INSERT INTO artifacts (id, code, name) values (15, 'DO', 'Data Object');
INSERT INTO artifacts (id, code, name) values (16, 'DF', 'Data File');
INSERT INTO artifacts (id, code, name) values (17, 'TAB', 'Table');
INSERT INTO artifacts (id, code, name) values (18, 'SYS', 'System');
INSERT INTO artifacts (id, code, name) values (19, 'MOD', 'Module');
INSERT INTO artifacts (id, code, name) values (20, 'SMD', 'Submodule');
INSERT INTO artifacts (id, code, name) values (21, 'PROJ', 'Project');
INSERT INTO artifacts (id, code, name) values (22, 'DOM', 'Domain');
INSERT INTO artifacts (id, code, name) values (23, 'PTY', 'Party');
INSERT INTO artifacts (id, code, name) values (24, 'DT', 'Data Type');
CREATE TABLE title_patterns
(
  id serial primary key,
  artifact smallint REFERENCES artifacts (id),
  pattern varchar(255),
  pattern_type varchar(5), -- DOC, PROJ,
  unique (artifact, pattern_type)
);

CREATE TABLE mapped_elements
(
  guid varchar(50) primary key,
  artifact smallint REFERENCES artifacts (id), -- EA element is mapped to SYS, UC, SCR etc.
  abbreviation varchar(100) -- abbreviation entered by user when creating mapping - used to create page title if it contains element abbreviation
);

CREATE TABLE mapped_methods
(
  guid varchar(50) primary key,
  parent_guid varchar(50),
  artifact smallint REFERENCES artifacts (id)
);

CREATE TABLE mappings
(
  id serial primary key,
  page_id varchar(10),
  element_guid varchar(50) REFERENCES mapped_elements (guid),
  method_guid varchar(50) REFERENCES mapped_methods (guid),
  page_title varchar(255),
  status smallint REFERENCES e_mapping_statuses (id),
  status_updated_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  created_at TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  type varchar(5), -- DOC, PROJ,
  system_mapping_id int REFERENCES mappings (id),
  module_mapping_id int REFERENCES mappings (id),
  submodule_mapping_id int REFERENCES mappings (id),
  interface_mapping_id int REFERENCES mappings (id),
  project_mapping_id int REFERENCES mappings (id) 
);

CREATE UNIQUE INDEX page_element_idx ON mappings (page_id, element_guid);
CREATE UNIQUE INDEX page_method_idx ON mappings (page_id, method_guid);
CREATE UNIQUE INDEX page_idx ON mappings (page_id);

CREATE TABLE artifact_images
(
  id serial primary key,
  name varchar(255),
  image bytea,  
  image_exported bytea,          
  mapping_id int REFERENCES mappings (id)
);

CREATE TABLE artifact_image_objects
(
  id serial primary key,
  number int,  
  name varchar(99), 
  point_1_x double precision,
  point_1_y double precision,
  point_2_x double precision,
  point_2_y double precision,
  point_3_x double precision,
  point_3_y double precision,
  point_4_x double precision,
  point_4_y double precision,    
  circle_size smallint,        
  artifact_image_id int REFERENCES artifact_images (id) ON DELETE CASCADE
);




CREATE TABLE admin_settings
(
  admin_password varchar(40)
);
INSERT INTO admin_settings (admin_password) VALUES ('5baa61e4c9b93f3f0682250b6cf8331b7ee68fd8'); -- admin

INSERT INTO title_patterns (artifact, pattern, pattern_type) values (1, '$type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (1, '$proj_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (2, '$type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (3, '$type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (3, '$proj_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (4, '$type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (4, '$proj_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (5, '$sys_abbrev $type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (5, '$proj_abbrev $sys_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (6, '$sys_abbrev $type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (6, '$proj_abbrev $sys_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (7, '$sys_abbrev $type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (7, '$proj_abbrev $sys_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (8, '$type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (8, '$proj_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (9, '$sys_abbrev $type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (9, '$proj_abbrev $sys_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (10, '$sys_abbrev $type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (10, '$proj_abbrev $sys_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (11, '$sys_abbrev $type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (11, '$proj_abbrev $sys_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (12, '$sys_abbrev $type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (12, '$proj_abbrev $sys_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (13, '$type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (13, '$proj_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (14, '$sys_abbrev $type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (14, '$proj_abbrev $sys_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (15, '$sys_abbrev $type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (15, '$proj_abbrev $sys_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (16, '$sys_abbrev $type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (16, '$proj_abbrev $sys_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (17, '$sys_abbrev $type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (17, '$proj_abbrev $sys_abbrev $type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (18, '$type_code $abbrev', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (18, '$proj_abbrev $type_code $abbrev', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (19, '$sys_abbrev $type_code $abbrev', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (19, '$proj_abbrev $sys_abbrev $type_code $abbrev', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (20, '$sys_abbrev $mod_abbrev $type_code $abbrev', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (20, '$proj_abbrev $sys_abbrev $mod_abbrev  $type_code $abbrev', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (21, '$type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (21, '$type_code $name', 'PROJ');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (22, '$type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (23, '$type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (24, '$type_code $name', 'DOC');
INSERT INTO title_patterns (artifact, pattern, pattern_type) values (24, '$proj_abbrev $type_code $name', 'PROJ');

CREATE TABLE diagram_images
(
  diagram_guid varchar(50),
  diagram_name varchar(100),
  page_url varchar(100),
  page_name varchar(100),
  date_regenerated timestamp,
  is_clickable smallint,
  PRIMARY KEY (diagram_guid, page_url)
);


-- ALTER TABLE public.mapped_elements OWNER TO easynchrouser;
-- ALTER TABLE public.mapped_methods OWNER TO easynchrouser;
-- ALTER TABLE public.mappings OWNER TO easynchrouser;
-- ALTER TABLE public.e_mapping_statuses OWNER TO easynchrouser;
-- ALTER TABLE public.artifacts OWNER TO easynchrouser;
-- ALTER TABLE public.title_patterns OWNER TO easynchrouser;
-- ALTER TABLE public.artifact_image_objects OWNER TO easynchrouser;
-- ALTER TABLE public.artifact_images OWNER TO easynchrouser;
-- ALTER TABLE public.settings OWNER TO easynchrouser;
-- ALTER TABLE public.admin_settings OWNER TO easynchrouser;

